@@ -66,9 +66,19 @@ class Set(PlanOutOp):
 
   def execute(self, mapper):
     var, value = self.args['var'], self.args['value']
-    # if a salt is not specified, use the variable name as the salt
+    if mapper.has_override(var):
+      return
+
+    # if the value is operator, add the name of the variable as a salt if no
+    # salt is provided.
     if ops.Operators.isOperator(value) and 'salt' not in value:
       value['salt'] = var
+
+    # if we are setting the special variable, experiment_salt, update mapper
+    # object accordingly with the new experiment-level salt
+    if var == 'experiment_salt':
+      mapper.experiment_salt = value
+
     mapper.set(var, mapper.evaluate(value))
 
   def validate(self):
@@ -79,13 +89,6 @@ class Set(PlanOutOp):
     return "%s = %s;" % (self.args['var'], strp)
 
 
-class SetOverride(Set):
-  def execute(self, mapper):
-    var, value = self.args['var'], self.args['value']
-    if not mapper.has_override(var):
-      super(SetOverride, self).execute(mapper)
-
-
 class Array(PlanOutOp):
   def options(self):
     return {'values': {'required': 1, 'description': 'array of values'}}
@@ -105,6 +108,22 @@ class Array(PlanOutOp):
     f = "[%s]" % ', '.join(l)
     return f
 
+class Coalesce(PlanOutOp):
+  def options(self):
+    return {'values': {'required': 1, 'description': 'array of values'}}
+
+  def execute(self, mapper):
+    for x in self.args['values']:
+      eval_x = mapper.evaluate(x)
+      if eval_x is not None:
+        return eval_x
+    return None
+
+  def pretty(self):
+    values = Operators.strip_array(self.args['values'])
+    pretty_c = [Operators.pretty(i) for i in values]
+    return 'coalesce(%s)' % ', '.join(pretty_c)
+
 
 class Index(PlanOutOpSimple):
   def options(self):
@@ -113,6 +132,18 @@ class Index(PlanOutOpSimple):
       'index': {'required': 1, 'description': 'index'}}
 
   def simpleExecute(self):
+    # returns value at index if it exists, returns None otherwise.
+    # works with both lists and dictionaries.
+    base, index = self.parameters['base'], self.parameters['index']
+    if type(base) is list:
+      if index >= 0 and index < len(base):
+        return base[index]
+      else:
+        return None
+    else:
+      # assume we have a dictionary
+      return base.get(index)
+
     return self.parameters['base'][self.parameters['index']]
 
   def pretty(self):
@@ -254,6 +285,10 @@ class Divide(PlanOutOpBinary):
   def binaryExecute(self, left, right):
     return float(left) / float(right)
 
+class Round(PlanOutOpUnary):
+  def unaryExecute(self, value):
+    return round(value)
+
 class Not(PlanOutOpUnary):
   def unaryExecute(self, value):
     return not value
