@@ -23,10 +23,12 @@ class Operators():
       "%": core.Mod,
       "/": core.Divide,
       "not": core.Not,
+      "round": core.Round,
       "negative": core.Negative,
       "min": core.Min,
       "max": core.Max,
       "length": core.Length,
+      "coalesce": core.Coalesce,
       "product": core.Product,
       "sum": core.Sum,
       "randomFloat": random.RandomFloat,
@@ -38,11 +40,6 @@ class Operators():
       "sample": random.Sample
     }
 
-  @staticmethod
-  def enable_overrides():
-    import core
-    Operators.operators['set'] = core.SetOverride
-
   @staticmethod
   def isOperator(op):
     return \
